.. _index-web:

===========================
Web Tools
===========================

.. module:: dynts.web

Dynts comes with a ``web`` and a ``media`` module which can be used to display timeseries
data on the web using Python and Javascript.

It can be used as a django__ application as well simply by adding
``dynts`` in the installed application.

Contents
==================

.. toctree::
   :maxdepth: 1
   
   ecoplot
   plugin

__ http://www.djangoproject.com/